@@ -5,7 +5,7 @@ import os
 
 import typer
 
-from ascend_io_cli.support import (OutputFormat, hostname_callback, max_workers_callback, output_callback, verbosity_callback)
+from ascend_io_cli.support import (OutputFormat, hostname_callback, max_workers_callback, output_callback, verbosity_callback, verify_ssl_callback)
 
 # Loop through all commands and add them as sub-commands here.
 app = typer.Typer(name='ascend')
@@ -28,6 +28,7 @@ def app_callback(
         is_eager=True,
     ),
     max_workers: int = typer.Option(10, callback=max_workers_callback, help='Maximum threads to use', is_eager=True),
+    verify_ssl: bool = typer.Option(True, callback=verify_ssl_callback, is_eager=True, hidden=True, show_default=False),
 ):
   pass
 
