@@ -81,7 +81,7 @@ def _hydrate_component(data_service_id: str, dataflow_id: str, component_id: str
   v2_name = Path(base_dir).resolve().joinpath(f'{component_id}.py')
   file = next(filter(lambda x: os.path.exists(x), [v2_name]), None)
   if not file:
-    raise Exception(f"component file for {data_service_id}.{dataflow_id}.{component_id} not found in {base_dir}")
+    raise Exception(f"component file for {data_service_id}.{dataflow_id}.{component_id} not found at {base_dir}")
   logging.debug(f'Loading at {file}')
   spec = importlib.util.spec_from_file_location("local", file)
   module_d = importlib.util.module_from_spec(spec)
@@ -93,7 +93,7 @@ def _hydrate_dataflow(data_service_id: str, dataflow_id: str, new_data_service_i
   v2_name = Path(base_dir).resolve().joinpath(f'{dataflow_id}.py')
   file = next(filter(lambda x: os.path.exists(x), [v2_name]), None)
   if not file:
-    raise Exception(f"dataflow file for {data_service_id} not found in {v2_name}")
+    raise Exception(f"dataflow file for {data_service_id}.{dataflow_id} not found at {v2_name}")
   logging.debug(f'Loading at {file}')
   spec = importlib.util.spec_from_file_location("local", file)
   module_d = importlib.util.module_from_spec(spec)
@@ -105,7 +105,7 @@ def _hydrate_data_service(data_service_id: str, new_data_service_id: str, base_d
   v2_name = Path(base_dir).resolve().joinpath(f'{data_service_id}.py')
   file = next(filter(lambda x: os.path.exists(x), [v2_name]), None)
   if not file:
-    raise Exception(f"dataservice file for {data_service_id} not found in {base_dir}")
+    raise Exception(f"dataservice file for {data_service_id} not found at {base_dir}")
   logging.debug(f'Loading at {file}')
   spec = importlib.util.spec_from_file_location("local", file)
   module_d = importlib.util.module_from_spec(spec)
@@ -135,7 +135,7 @@ def clone_dataflow(
     write_dir = Path(temp_dir).resolve().joinpath(f'{from_service}', f'{from_dataflow}')
     write_dir.mkdir(parents=True, exist_ok=True)
     download_dataflow(client, data_service_id=from_service, dataflow_id=from_dataflow, resource_base_path=str(write_dir), template_dir=template_dir)
-    hydrated = _hydrate_dataflow(from_service, from_dataflow, data_service_id, new_dataflow_id, write_dir)
+    hydrated = _hydrate_dataflow(from_service, from_dataflow, to_data_service, new_dataflow_id, str(write_dir))
     DataflowApplier(client).apply(data_service_id=to_data_service, dataflow=hydrated, delete=True, dry_run=False)
     print_response(ctx, hydrated)
 
