@@ -1,10 +1,12 @@
 import concurrent
+import fnmatch
 import logging
 import os
 import shutil
 from concurrent.futures import ThreadPoolExecutor
 from datetime import datetime
 from pathlib import Path
+from typing import List
 
 import typer
 from ascend.sdk.render import TEMPLATES_V2, download_component, download_data_service, download_dataflow
@@ -22,20 +24,60 @@ def _configure_write_dir(write_dir: Path, unique: bool) -> Path:
   return write_dir
 
 
+def _load_ignore_matches(write_dir: Path) -> List[str]:
+  ignore = []
+  ignore_file = write_dir.joinpath('.ascendignore')
+  if ignore_file.exists():
+    with ignore_file.open('r', encoding='UTF-8') as file:
+      while line := file.readline():
+        line = line.strip()
+        if line:
+          ignore.append(line)
+  if '.git' not in ignore:
+    ignore.append('.git')
+  if '.ascendignore' not in ignore:
+    ignore.append('.ascendignore')
+  return ignore
+
+
+def _files_accepted(matches: List[str], base_dir: Path) -> List[str]:
+  """Identify the files that should be accepted for cleanup.
+  Ignores files that should be kept/preserved."""
+  accepted_files = []
+
+  for root, dirnames, filenames in os.walk(base_dir, topdown=True):
+    for dirname in dirnames:
+      for ignore in matches:
+        if fnmatch.fnmatch(dirname, ignore) or fnmatch.fnmatch(dirname + '/', ignore):
+          dirnames.remove(dirname) # remove any ignored directories from further consideration in os.walk
+
+    for filename in filenames:
+      full_file_path = os.path.join(root, filename)
+      keep_file = True
+      for ignore in matches:
+        if fnmatch.fnmatch(full_file_path, ignore) or fnmatch.fnmatch(filename, ignore) or filename == ignore:
+          keep_file = False
+          break
+      if keep_file:
+        accepted_files.append(full_file_path)
+
+  return accepted_files
+
+
 def _clean_write_dir(write_dir: Path, purge: bool):
-  """The purge option will also remove the .git folder"""
+  """The purge option will remove everything"""
   if write_dir and write_dir.exists():
+    assert write_dir != '/' # never remove root protection
+
     if purge:
       shutil.rmtree(write_dir)
     else:
-      for ls_dir in filter((lambda d: d != '.git'), os.listdir(write_dir)):
-        target = write_dir.joinpath(str(ls_dir))
-        if target.is_dir():
-          shutil.rmtree(target)
-        elif target.is_file():
-          os.remove(target)
-        else:
-          logging.debug(f'clean target was neither a file or a directory: {target}')
+      # assume .ascendignore in current working directory
+      ignore_files = _load_ignore_matches(Path('.'))
+      files = _files_accepted(ignore_files, write_dir)
+      files.reverse()
+      for f in files:
+        os.remove(f)
 
 
 @app.command()
